[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[xen master] x86/Intel: skip PLATFORM_INFO reads on family 0xf



commit a8b31239ae2f8d7bba10603ad8a4ba544a067b3c
Author:     Jan Beulich <jbeulich@xxxxxxxx>
AuthorDate: Mon Feb 14 10:04:35 2022 +0100
Commit:     Jan Beulich <jbeulich@xxxxxxxx>
CommitDate: Mon Feb 14 10:04:35 2022 +0100

    x86/Intel: skip PLATFORM_INFO reads on family 0xf
    
    This avoids unnecessary (and always somewhat scary) log messages for the
    recovered from #GP(0).
    
    Signed-off-by: Jan Beulich <jbeulich@xxxxxxxx>
    Acked-by: Roger Pau Monné <roger.pau@xxxxxxxxxx>
---
 xen/arch/x86/cpu/common.c | 7 +++++--
 xen/arch/x86/cpu/intel.c  | 2 +-
 2 files changed, 6 insertions(+), 3 deletions(-)

diff --git a/xen/arch/x86/cpu/intel.c b/xen/arch/x86/cpu/intel.c
index 06b0e552cc..5ec67cf9e0 100644
--- a/xen/arch/x86/cpu/intel.c
+++ b/xen/arch/x86/cpu/intel.c
@@ -455,7 +455,7 @@ static void intel_log_freq(const struct cpuinfo_x86 *c)
         }
     }
 
-    if ( rdmsr_safe(MSR_INTEL_PLATFORM_INFO, msrval) )
+    if ( c->x86 == 0xf || rdmsr_safe(MSR_INTEL_PLATFORM_INFO, msrval) )
         return;
     max_ratio = msrval >> 8;
 
diff --git a/xen/arch/x86/cpu/common.c b/xen/arch/x86/cpu/common.c
index c4f07f2d1d..3d61d95386 100644
--- a/xen/arch/x86/cpu/common.c
+++ b/xen/arch/x86/cpu/common.c
@@ -127,9 +127,12 @@ bool __init probe_cpuid_faulting(void)
 
        /*
         * Don't bother looking for CPUID faulting if we aren't virtualised on
         * AMD or Hygon hardware - it won't be present.
         */
-       if ((boot_cpu_data.x86_vendor & (X86_VENDOR_AMD | X86_VENDOR_HYGON)) &&
+       if (((boot_cpu_data.x86_vendor & (X86_VENDOR_AMD | X86_VENDOR_HYGON)) ||
+            ((boot_cpu_data.x86_vendor == X86_VENDOR_INTEL) &&
+             boot_cpu_data.x86 == 0xf)) &&
            !cpu_has_hypervisor)
                return false;
 
@@ -127,9 +127,12 @@ bool __init probe_cpuid_faulting(void)
        /*
         * Don't bother looking for CPUID faulting if we aren't virtualised on
-        * AMD or Hygon hardware - it won't be present.
+        * AMD or Hygon hardware - it won't be present.  Likewise for Fam0F
+        * Intel hardware.
         */
--
generated by git-patchbot for /home/xen/git/xen.git#master



 


Rackspace

Lists.xenproject.org is hosted with RackSpace, monitoring our
servers 24x7x365 and backed by RackSpace's Fanatical Support®.